@@ -2,11 +2,13 @@ from serial import Serial
 from . import InetboxLINProtocol, InetboxApp, Lin
 import miqro
 from os import environ
+from datetime import timedelta
 
 
 class TrumaService(miqro.Service):
     SERVICE_NAME = "truma"
     LOOP_INTERVAL = 0.001
+    VALUE_UPDATE_MAX_INTERVAL = timedelta(minutes=2)
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -15,7 +17,9 @@ class TrumaService(miqro.Service):
         self.inetprotocol = InetboxLINProtocol(
             self.inetapp, "DEBUG_PROTOCOL" in environ
         )
-        self.serial = Serial("/dev/ttyS0", 9600, timeout=0.03)
+        serial_device = self.service_config.get("serial_device", "/dev/serial0")
+        self.serial = Serial(serial_device, 9600, timeout=0.03)
+        self.log.info(f"Using serial device {serial_device}")
         self.lin = Lin(self.inetprotocol, "DEBUG_LIN" in environ)
 
     def _loop_step(self):
@@ -31,11 +35,11 @@ class TrumaService(miqro.Service):
     def send_status(self):
         if self.inetapp.status_updated:
             self.publish_json_keys(
-                self.inetapp.get_all(), "control_status", only_if_changed=True
+                self.inetapp.get_all(), "control_status", only_if_changed=self.VALUE_UPDATE_MAX_INTERVAL
             )
 
         self.publish_json_keys(
-            self.inetapp.display_status, "display_status", only_if_changed=True
+            self.inetapp.display_status, "display_status", only_if_changed=self.VALUE_UPDATE_MAX_INTERVAL
         )
 
     @miqro.handle("set/#")
@@ -50,3 +54,6 @@ class TrumaService(miqro.Service):
 
 def run():
     miqro.run(TrumaService)
+
+if __name__ == "__main__":
+    run()
\ No newline at end of file
